Module config

Module config 

Local credential storage, persisted runtime config, and time utilities.

Structs

AppConfig
Persisted runtime defaults used by serve and daemon install.
AppConfigStore
Loads and saves the persisted application configuration file.
AuthStore
Credentials

Functions

now_unix